@@ -162,8 +162,7 @@ public:
             case Symbol::Kind::Field:
                 expectToken(in_, JsonParser::Token::String);
                 if (s.extra<string>() != in_.stringValue()) {
-                    throw Exception(boost::format("Incorrect field: expected \"%1%\" but got \"%2%\".") % 
-                        s.extra<string>() % in_.stringValue());
+                    throw Exception(R"(Incorrect field: expected "{}" but got "{}".)", s.extra<string>(), in_.stringValue());
                 }
                 break;
             default:
@@ -241,8 +240,7 @@ int32_t JsonDecoder<P>::decodeInt() {
     expect(JsonParser::Token::Long);
     int64_t result = in_.longValue();
     if (result < INT32_MIN || result > INT32_MAX) {
-        throw Exception(boost::format("Value out of range for Avro int: %1%")
-                        % result);
+        throw Exception("Value out of range for Avro int: {}", result);
     }
     return static_cast<int32_t>(result);
 }
@@ -496,6 +494,7 @@ public:
 template<typename P, typename F>
 void JsonEncoder<P, F>::init(OutputStream &os) {
     out_.init(os);
+    parser_.reset();
 }
 
 template<typename P, typename F>
