@@ -108,11 +108,10 @@ const char *basicSchemas[] = {
 
     // Custom attribute(s) for field in record
     "{\"type\": \"record\",\"name\": \"Test\",\"fields\": "
-        "[{\"name\": \"f1\",\"type\": \"long\",\"extra field\": \"1\"}]}",
+    "[{\"name\": \"f1\",\"type\": \"long\",\"extra field\": \"1\"}]}",
     "{\"type\": \"record\",\"name\": \"Test\",\"fields\": "
-        "[{\"name\": \"f1\",\"type\": \"long\","
-        "\"extra field1\": \"1\",\"extra field2\": \"2\"}]}"
-};
+    "[{\"name\": \"f1\",\"type\": \"long\","
+    "\"extra field1\": \"1\",\"extra field2\": \"2\"}]}"};
 
 const char *basicSchemaErrors[] = {
     // Record
@@ -227,12 +226,12 @@ const char *roundTripSchemas[] = {
 
     // Custom fields
     "{\"type\":\"record\",\"name\":\"Test\",\"fields\":"
-        "[{\"name\":\"f1\",\"type\":\"long\",\"extra_field\":\"1\"},"
-        "{\"name\":\"f2\",\"type\":\"int\"}]}",
+    "[{\"name\":\"f1\",\"type\":\"long\",\"extra_field\":\"1\"},"
+    "{\"name\":\"f2\",\"type\":\"int\"}]}",
     "{\"type\":\"record\",\"name\":\"Test\",\"fields\":"
-        "[{\"name\":\"f1\",\"type\":\"long\",\"extra_field\":\"1\"},"
-        "{\"name\":\"f2\",\"type\":\"int\","
-        "\"extra_field1\":\"21\",\"extra_field2\":\"22\"}]}",
+    "[{\"name\":\"f1\",\"type\":\"long\",\"extra_field\":\"1\"},"
+    "{\"name\":\"f2\",\"type\":\"int\","
+    "\"extra_field1\":\"21\",\"extra_field2\":\"22\"}]}",
 };
 
 const char *malformedLogicalTypes[] = {
@@ -368,7 +367,7 @@ static void testLogicalTypes() {
         \"logicalType\": \"uuid\"\n\
     }";
     // AVRO-2923 Union with LogicalType
-    const char* unionType = "[\n\
+    const char *unionType = "[\n\
         {\"type\":\"string\", \"logicalType\":\"uuid\"},\"null\"\n\
     ]";
     {
